@@ -592,6 +592,7 @@ void handleArgs(int argc, char *argv[])
       theDay = greg_today.dd;      /* printc theDay of theMonth */
       yearDirty = 1;
       printOmer_sw = 1;
+      hebrewDates_sw = 0;
    }
 
    if (yahrtzeitFileName != NULL) {
@@ -649,7 +650,7 @@ void handleArgs(int argc, char *argv[])
                            ZMAN_PLAG_HAMINCHA | ZMAN_SUNSET | ZMAN_TZAIT_42);
    }
 
-   if (!TZ_INFO && (zemanim_sw || candleLighting_sw)) {
+   if (!TZ_INFO && (zemanim_sw || candleLighting_sw || printSunriseSunset_sw)) {
       set_default_city();
    }
 
